@@ -344,19 +344,19 @@ void TimelineCtrl::_updateProfileImage(QString image)
  */
 void TimelineCtrl::_dialogLocation()
 {
-    if(!_timelineView->_locationCheckBox->isChecked()) {
-        dialog = new DialogView(DialogView::Location,"Choose one method to obtain your coordinates");
-        connect(dialog, SIGNAL(getIP()), _timelineView, SLOT(getIPCoordinates()));
-        connect(dialog, SIGNAL(getGPS()), _timelineView, SLOT(getGPSCoordinates()));
-        connect(dialog, SIGNAL(cancelPressed()), _timelineView, SLOT(setLocationCheckboxFalse()));
-        _scene->addItem(dialog);
-    }
-    else {
-        isGPS = false;
-        #ifdef LIBLOCATION
-            _timelineView->_gpsLocation->stop();
-        #endif // LIBLOCATION
-    }
+//    if(!_timelineView->_locationCheckBox->isChecked()) {
+//        dialog = new DialogView(DialogView::Location,"Choose one method to obtain your coordinates");
+//        connect(dialog, SIGNAL(getIP()), _timelineView, SLOT(getIPCoordinates()));
+//        connect(dialog, SIGNAL(getGPS()), _timelineView, SLOT(getGPSCoordinates()));
+//        connect(dialog, SIGNAL(cancelPressed()), _timelineView, SLOT(setLocationCheckboxFalse()));
+//        _scene->addItem(dialog);
+//    }
+//    else {
+//        isGPS = false;
+//        _timelineView->_gpsLocation->stop();
+//    }
+        if(!_timelineView->_locationCheckBox->isChecked())
+            _timelineView->getIPCoordinates();    
 }
 
 /*!
@@ -364,17 +364,15 @@ void TimelineCtrl::_dialogLocation()
  */
 void TimelineCtrl::_handleGPSLocation()
 {
-    qDebug() << "+ " << __PRETTY_FUNCTION__;
-    #ifdef LIBLOCATION
-    if(_timelineView->_locationCheckBox->isChecked())
-        QMaemo5InformationBox::information(NULL, tr("GPS information updated!"), QMaemo5InformationBox::DefaultTimeout);
-    else
-        QMaemo5InformationBox::information(NULL, tr("GPS stopped"), QMaemo5InformationBox::DefaultTimeout);
-
-    gpsLatitude = QString::number(_timelineView->_gpsLocation->getLat());
-    gpsLongitude = QString::number(_timelineView->_gpsLocation->getLon());
-    #endif // LIBLOCATION
-    isGPS = true;
+//    qDebug() << "+ " << __PRETTY_FUNCTION__;
+//    if(_timelineView->_locationCheckBox->isChecked())
+//        QMaemo5InformationBox::information(NULL, tr("GPS information updated!"), QMaemo5InformationBox::DefaultTimeout);
+//    else
+//        QMaemo5InformationBox::information(NULL, tr("GPS stopped"), QMaemo5InformationBox::DefaultTimeout);
+//
+//    gpsLatitude = QString::number(_timelineView->_gpsLocation->getLat());
+//    gpsLongitude = QString::number(_timelineView->_gpsLocation->getLon());
+//    isGPS = true;
 }
 
 void TimelineCtrl::_createListsScene()
@@ -390,12 +388,10 @@ void TimelineCtrl::_createListsScene()
     _timelineView->view2->viewport()->setPalette(p);
     _timelineView->view2->setAttribute(Qt::WA_TranslucentBackground, true);
 
-    #ifdef LIBLOCATION
-        QAbstractKineticScroller *scroller = _timelineView->view2->property("kineticScroller")
+    QAbstractKineticScroller *scroller = _timelineView->view2->property("kineticScroller")
                                              .value<QAbstractKineticScroller *>();
-        if (scroller)
-            scroller->setEnabled(true);
-    #endif // LIBLOCATION
+    if (scroller)
+        scroller->setEnabled(true);
 }
 
 void TimelineCtrl::_addHomeTimelineToScene(StatusList *homeTimeline)
