@@ -42,9 +42,7 @@ TimelineView::TimelineView(void)
 
     view2 = new QGraphicsView;
 
-    #ifdef LIBLOCATION
-        _gpsLocation = new Maemo5GPS;
-    #endif // LIBLOCATION
+//    _gpsLocation = new Maemo5GPS;
 }
 
 /*!
@@ -65,10 +63,8 @@ TimelineView::~TimelineView()
     if(view2)
         delete view2;
 
-    #ifdef LIBLOCATION
-        if(this->_gpsLocation)
-            delete this->_gpsLocation;
-    #endif // LIBLOCATION
+//    if(this->_gpsLocation)
+//        delete this->_gpsLocation;
 }
 
 /*!
@@ -604,9 +600,7 @@ void TimelineView::getIPCoordinates()
 {
     qDebug() << "+ " << __PRETTY_FUNCTION__;
 
-    #ifdef LIBLOCATION
-        QMaemo5InformationBox::information(NULL, tr("Acquiring geographical information through your IP"), QMaemo5InformationBox::DefaultTimeout);
-    #endif // LIBLOCATION
+    QMaemo5InformationBox::information(NULL, tr("Acquiring geographical information through your IP"), QMaemo5InformationBox::DefaultTimeout);
 
     _ipLocation->getLocation();
 }
@@ -618,10 +612,8 @@ void TimelineView::_showIpLocationInfo(double latitude, double longitude)
 {
     qDebug() << "+ " << __PRETTY_FUNCTION__;
 
-    #ifdef LIBLOCATION
-        QMaemo5InformationBox::information(NULL, tr("GOT IT! Latitude = %1, Longitude = %2").arg(latitude).arg(longitude),
+    QMaemo5InformationBox::information(NULL, tr("GOT IT! Latitude = %1, Longitude = %2").arg(latitude).arg(longitude),
                                            QMaemo5InformationBox::DefaultTimeout);
-    #endif // LIBLOCATION
 }
 
 /*!
@@ -638,13 +630,11 @@ void TimelineView::_emitChangeAvatar(QString image)
  */
 void TimelineView::getGPSCoordinates()
 {
-    qDebug() << "+ " << __PRETTY_FUNCTION__;
-
-    #ifdef LIBLOCATION
-        _gpsLocation->get_agnss();
-        QMaemo5InformationBox::information(NULL, tr("Acquiring GPS information"), QMaemo5InformationBox::DefaultTimeout);
-        connect(_gpsLocation, SIGNAL(getOK_agnss()), this, SIGNAL(gotGPS()));
-    #endif // LIBLOCATION
+//    qDebug() << "+ " << __PRETTY_FUNCTION__;
+//
+//    _gpsLocation->get_agnss();
+//    QMaemo5InformationBox::information(NULL, tr("Acquiring GPS information"), QMaemo5InformationBox::DefaultTimeout);
+//    connect(_gpsLocation, SIGNAL(getOK_agnss()), this, SIGNAL(gotGPS()));
 }
 
 /*!
