@@ -43,10 +43,8 @@
 
 #include <QtDBus>
 
-#ifdef LIBLOCATION
-    #include <QMaemo5InformationBox>
-    #include <location/maemo5gps.h>
-#endif // LIBLOCATION
+#include <QMaemo5InformationBox>
+//#include <location/maemo5gps.h>
 
 #include "backend.h"
 #include "applicationItems/lineedit.h"
@@ -209,9 +207,7 @@ public:
     bool isReply;
     QString m_statusId;
 
-    #ifdef LIBLOCATION
-        Maemo5GPS *_gpsLocation;
-    #endif // LIBLOCATION
+//    Maemo5GPS *_gpsLocation;
 };
 
 #endif // TIMELINEVIEW_H
