@@ -165,7 +165,7 @@ class QTwitLib : public Core
          * WARNING!!! Not described in API.
          * @param source Optional. Twitter client name, must be registered at http://twitter.com/help/request_source
          */
-        EXPORT void PostNewStatus(QString status, QString lat, QString lon, quint64 in_reply_to_status_id = NULL, QString source = "");
+        EXPORT void PostNewStatus(QString status, QString lat, QString lon, QString in_reply_to_status_id = NULL, QString source = "");
 //=====================================================================
         /**
          * Returns the 20 most recent mentions (status containing @username) for the authenticating user.
