@@ -35,9 +35,7 @@
 #include <QNetworkRequest>
 #include <QNetworkReply>
 
-#ifdef LIBLOCATION
-    #include <QMaemo5InformationBox>
-#endif // LIBLOCATION
+#include <QMaemo5InformationBox>
 
 /*!
  * \class UrlShortener
